==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Voronoi_diagram_2/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"index.html#secvda2intro":[0,0],
"index.html#secvda2traits":[0,2],
"index.html#subsecvda2efficiency":[0,3,0],
"models.html":[2],
"modules.html":[1],
"namespaceCGAL.html":[5,0],
"pages.html":[],
"structCGAL_1_1Apollonius__graph__adaptation__traits__2.html":[1,0,3,2],
"structCGAL_1_1Apollonius__graph__adaptation__traits__2.html#a49fdc03ed8c3d6eebf76cf2175993a28":[1,0,3,2,0],
"structCGAL_1_1Apollonius__graph__caching__degeneracy__removal__policy__2.html":[1,0,3,0],
"structCGAL_1_1Apollonius__graph__caching__degeneracy__removal__policy__2.html#a85d976cd3810207b22ea3170c5c7fbc7":[1,0,3,0,0],
"structCGAL_1_1Apollonius__graph__degeneracy__removal__policy__2.html":[1,0,3,1],
"structCGAL_1_1Apollonius__graph__degeneracy__removal__policy__2.html#adbd136610e5744b62dcb65b0eb726555":[1,0,3,1,0],
"structCGAL_1_1Delaunay__triangulation__adaptation__traits__2.html":[1,0,1,2],
"structCGAL_1_1Delaunay__triangulation__adaptation__traits__2.html#a0770bf56e23dc29ade874c0eff28b222":[1,0,1,2,0],
"structCGAL_1_1Delaunay__triangulation__caching__degeneracy__removal__policy__2.html":[1,0,1,0],
"structCGAL_1_1Delaunay__triangulation__caching__degeneracy__removal__policy__2.html#a3602642caeccb04525efca8e8479ca64":[1,0,1,0,0],
"structCGAL_1_1Delaunay__triangulation__degeneracy__removal__policy__2.html":[1,0,1,1],
"structCGAL_1_1Delaunay__triangulation__degeneracy__removal__policy__2.html#a9d4ac73f12a2448620dadba8dd920344":[1,0,1,1,0],
"structCGAL_1_1Identity__policy__2.html":[1,0,5],
"structCGAL_1_1Identity__policy__2.html#a471d7c9517fe0a4466bffaa1b8b1738e":[1,0,5,0],
"structCGAL_1_1Regular__triangulation__adaptation__traits__2.html":[1,0,1,5],
"structCGAL_1_1Regular__triangulation__adaptation__traits__2.html#a399b316d413c46204fc750e274bd6d6c":[1,0,1,5,0],
"structCGAL_1_1Regular__triangulation__caching__degeneracy__removal__policy__2.html":[1,0,1,3],
"structCGAL_1_1Regular__triangulation__caching__degeneracy__removal__policy__2.html#a4d0921b2a8eeaf452c0a741b02b0979c":[1,0,1,3,0],
"structCGAL_1_1Regular__triangulation__degeneracy__removal__policy__2.html":[1,0,1,4],
"structCGAL_1_1Regular__triangulation__degeneracy__removal__policy__2.html#a699ca05b1643e8d30dd41f2a3bfeafb4":[1,0,1,4,0],
"structCGAL_1_1Segment__Delaunay__graph__adaptation__traits__2.html":[1,0,2,2],
"structCGAL_1_1Segment__Delaunay__graph__adaptation__traits__2.html#abd40185e2905498054142c01e9614496":[1,0,2,2,0],
"structCGAL_1_1Segment__Delaunay__graph__caching__degeneracy__removal__policy__2.html":[1,0,2,0],
"structCGAL_1_1Segment__Delaunay__graph__caching__degeneracy__removal__policy__2.html#a0d055a40c26de93182f625b1a5bb0360":[1,0,2,0,0],
"structCGAL_1_1Segment__Delaunay__graph__degeneracy__removal__policy__2.html":[1,0,2,1],
"structCGAL_1_1Segment__Delaunay__graph__degeneracy__removal__policy__2.html#ad17ecb55c4f7b6e2b47e701dec0bdf40":[1,0,2,1,0]
};

==> CGAL-6.0-doc_html.tar.xz: doc_html/Voronoi_diagram_2/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"group__PkgDrawVoronoiDiagram2.html#ga1fc3b3989f7a459742cbee58f9992537":[1,0,4,4],
"group__PkgDrawVoronoiDiagram2.html#ga20165684977c1f6ee2f02db3a6220c95":[1,0,4,1],
"group__PkgDrawVoronoiDiagram2.html#ga8b09704732f77a131b13d960fc3a0e94":[1,0,4,3],
"group__PkgDrawVoronoiDiagram2.html#ga9f796d687fd3b3c6099a44b4ff20376c":[1,0,4,2],
"group__PkgVoronoiDiagram2Concepts.html":[1,0,0],
"group__PkgVoronoiDiagram2Disks.html":[1,0,3],
"group__PkgVoronoiDiagram2Points.html":[1,0,1],
"group__PkgVoronoiDiagram2Ref.html":[1,0],
"group__PkgVoronoiDiagram2Segments.html":[1,0,2],
"index.html":[0],
"index.html":[],
"index.html#secvda2ap":[0,3],
"index.html#secvda2design":[0,1],
"index.html#secvda2drawvoronoi":[0,5],
"index.html#secvda2examples":[0,4],
"index.html#secvda2intro":[0,0],
"index.html#secvda2traits":[0,2],
"index.html#subsecvda2efficiency":[0,3,0],
"modules.html":[1],
"pages.html":[],
"structCGAL_1_1Apollonius__graph__adaptation__traits__2.html":[1,0,3,2],
"structCGAL_1_1Apollonius__graph__adaptation__traits__2.html#a49fdc03ed8c3d6eebf76cf2175993a28":[1,0,3,2,0],
"structCGAL_1_1Apollonius__graph__caching__degeneracy__removal__policy__2.html":[1,0,3,0],
"structCGAL_1_1Apollonius__graph__caching__degeneracy__removal__policy__2.html#a85d976cd3810207b22ea3170c5c7fbc7":[1,0,3,0,0],
"structCGAL_1_1Apollonius__graph__degeneracy__removal__policy__2.html":[1,0,3,1],
"structCGAL_1_1Apollonius__graph__degeneracy__removal__policy__2.html#adbd136610e5744b62dcb65b0eb726555":[1,0,3,1,0],
"structCGAL_1_1Delaunay__triangulation__adaptation__traits__2.html":[1,0,1,2],
"structCGAL_1_1Delaunay__triangulation__adaptation__traits__2.html#a0770bf56e23dc29ade874c0eff28b222":[1,0,1,2,0],
"structCGAL_1_1Delaunay__triangulation__caching__degeneracy__removal__policy__2.html":[1,0,1,0],
"structCGAL_1_1Delaunay__triangulation__caching__degeneracy__removal__policy__2.html#a3602642caeccb04525efca8e8479ca64":[1,0,1,0,0],
"structCGAL_1_1Delaunay__triangulation__degeneracy__removal__policy__2.html":[1,0,1,1],
"structCGAL_1_1Delaunay__triangulation__degeneracy__removal__policy__2.html#a9d4ac73f12a2448620dadba8dd920344":[1,0,1,1,0],
"structCGAL_1_1Graphics__scene__options__voronoi__diagram__2.html":[1,0,4,0],
"structCGAL_1_1Identity__policy__2.html":[1,0,5],
"structCGAL_1_1Identity__policy__2.html#a471d7c9517fe0a4466bffaa1b8b1738e":[1,0,5,0],
"structCGAL_1_1Regular__triangulation__adaptation__traits__2.html":[1,0,1,5],
"structCGAL_1_1Regular__triangulation__adaptation__traits__2.html#a399b316d413c46204fc750e274bd6d6c":[1,0,1,5,0],
"structCGAL_1_1Regular__triangulation__caching__degeneracy__removal__policy__2.html":[1,0,1,3],
"structCGAL_1_1Regular__triangulation__caching__degeneracy__removal__policy__2.html#a4d0921b2a8eeaf452c0a741b02b0979c":[1,0,1,3,0],
"structCGAL_1_1Regular__triangulation__degeneracy__removal__policy__2.html":[1,0,1,4],
"structCGAL_1_1Regular__triangulation__degeneracy__removal__policy__2.html#a699ca05b1643e8d30dd41f2a3bfeafb4":[1,0,1,4,0],
"structCGAL_1_1Segment__Delaunay__graph__adaptation__traits__2.html":[1,0,2,2],
"structCGAL_1_1Segment__Delaunay__graph__adaptation__traits__2.html#abd40185e2905498054142c01e9614496":[1,0,2,2,0],
"structCGAL_1_1Segment__Delaunay__graph__caching__degeneracy__removal__policy__2.html":[1,0,2,0],
"structCGAL_1_1Segment__Delaunay__graph__caching__degeneracy__removal__policy__2.html#a0d055a40c26de93182f625b1a5bb0360":[1,0,2,0,0],
"structCGAL_1_1Segment__Delaunay__graph__degeneracy__removal__policy__2.html":[1,0,2,1],
"structCGAL_1_1Segment__Delaunay__graph__degeneracy__removal__policy__2.html#ad17ecb55c4f7b6e2b47e701dec0bdf40":[1,0,2,1,0]
};
